<?php

/**
 * Read Kraehennes XML File
 */
class KPXMLReader
{
	function __construct( $xmlUrl, $cacheDir, $cacheTime, $cacheFile = 'KraehennestPodcasterCache.xml' )
	{
		$this -> xmlUrl = $xmlUrl;
		$this -> cacheDir = $cacheDir;
		$this -> cacheTime = $cacheTime;
		$this -> cacheFile = $cacheFile;
	}

	public function getElements()
	{
		// Check Cache usage
		if( file_exists( $this -> cacheDir . '/' . $this -> cacheFile ) && !empty( $this -> cacheTime ) )
		{
			// Read from cache if file is not older than now()-$cacheTime
			if( filemtime( $this -> cacheDir . '/' . $this -> cacheFile ) > (time() - $this -> cacheTime) )
				$this -> xmlUrl = $this -> cacheDir . '/' . $this -> cacheFile;
		}

		// Read XML
		$xmlData = file_get_contents( $this -> xmlUrl );

		// Write to cachefile
		if( !empty( $this -> cacheTime ) )
			file_put_contents( $this -> cacheDir . '/' . $this -> cacheFile, $xmlData );

		// Parse XML
		if( $xmlData )
		{
			$xml = new SimpleXMLElement( $xmlData );
			if( isset( $xml -> channel -> item ) )
			{
				$returnArr = array();
				foreach( $xml -> channel -> item AS $guidKey => $item )
				{
					if( strpos( $item -> link -> __toString(), '.mp3' ) !== false )
					{
						$returnArr[ $item -> title -> __toString() ] = $item -> link -> __toString();
					}
				}
				$returnArr = array_reverse( $returnArr, true );
				return $returnArr;
			}
			else	return false;
		}
		else return false;
	}
}

?>